@@ -1,11 +1,13 @@
 from .exceptions import CannotResolveError
-from .utils import get_path
+
 
 class Ref(object):
+
     def __init__(self, target, filter=None):
         super(Ref, self).__init__()
         self._target = target
         self._filter = filter
+
     def resolve(self, config):
         target = self._target
         if target.startswith("."):
@@ -13,10 +15,11 @@ class Ref(object):
         while target.startswith("."):
             target = target[1:]
             if config is None:
-                raise CannotResolveError("Cannot resolve {0}".format(self._target))
+                raise CannotResolveError(
+                    "Cannot resolve {0}".format(self._target))
             config = config.get_parent()
         try:
-            returned = get_path(config, target)
+            returned = config.get_path(target)
         except LookupError:
             raise CannotResolveError("Cannot resolve {0}".format(self._target))
         if self._filter is not None:
